@@ -2,9 +2,13 @@ package MojoX::Renderer::JSON::XS;
 use 5.010;
 use strict;
 use warnings;
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 use JSON::XS;
+use Mojo::Exception ();
+use Mojo::Util qw(monkey_patch);
+
+monkey_patch 'Mojo::Exception', TO_JSON => \&Mojo::Exception::to_string;
 
 our $JSON = JSON::XS->new->utf8->convert_blessed;
 
